<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT">
<context>
    <name>About</name>
    <message>
        <location filename="../src/about.ui" line="26"/>
        <location filename="../src/about.cpp" line="37"/>
        <source>About</source>
        <translation>Circa</translation>
    </message>
    <message>
        <location filename="../src/about.ui" line="82"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt; font-weight:700;&quot;&gt;UltimateDailyWallpaper&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/about.ui" line="89"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;Version: &lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/about.ui" line="133"/>
        <source>tab0</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/about.ui" line="178"/>
        <source>label_4</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/about.ui" line="191"/>
        <source>label_5</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/about.ui" line="204"/>
        <source>label_6</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/about.ui" line="230"/>
        <source>tab1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/about.ui" line="257"/>
        <source>TextLabel</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/about.ui" line="316"/>
        <source>pushButton_3</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/about.ui" line="335"/>
        <source>pushButton</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="38"/>
        <source>Currently used plugin</source>
        <translation>Plugin attualmente utilizzato</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="44"/>
        <source>License: GPL-3.0+</source>
        <translation>Licenza: GPL-3.0+</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="48"/>
        <source>Version: </source>
        <translation>Versione: </translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="54"/>
        <source>Patrice Coni</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="56"/>
        <source>Copyright © 2022 - </source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="62"/>
        <source>A wallpaper changer</source>
        <translation>Un&apos;applicazione per cambiare lo sfondo</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="64"/>
        <source>Close</source>
        <translation>Chiudere</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="65"/>
        <source>Visit website</source>
        <translation>Visita il sito</translation>
    </message>
    <message>
        <source>A simple application for changing wallpaper</source>
        <translation type="vanished">Una semplice applicazione per cambiare carta da parati</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/mainwindow.cpp" line="93"/>
        <source>No connection to the internet.
The application will be closed.</source>
        <translation>Nessuna connessione a Internet.
L&apos;applicazione verrà chiusa.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="119"/>
        <source>Reset</source>
        <translation>Resettare</translation>
    </message>
    <message>
        <source>The folder that containing the plugins was not found. Do you want to set the folder manually?</source>
        <translation type="vanished">La cartella contenente i plugin non è stata trovata. Si desidera impostare la cartella manualmente?</translation>
    </message>
    <message>
        <source>Select directory</source>
        <translation type="obsolete">Seleziona directory</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="119"/>
        <source>The folder containing the plugins was not found. Do you want to set the folder manually?</source>
        <translation>La cartella contenente i plugin non è stata trovata. Vuoi impostare la cartella manualmente?</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="125"/>
        <source>Select Plugin Folder</source>
        <translation>Seleziona la cartella dei plugin</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="134"/>
        <source>No Plugins Found</source>
        <translation>Nessun plugin trovato</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="135"/>
        <source>The folder does not contain any plugin files (*.so). Please choose a valid plugin folder.</source>
        <translation>La cartella non contiene file plugin (*.so). Scegli una cartella plugin valida.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="323"/>
        <location filename="../src/mainwindow.cpp" line="334"/>
        <location filename="../src/mainwindow.cpp" line="811"/>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="323"/>
        <source>No plugins found.</source>
        <translation>Nessun plugin trovato.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="329"/>
        <location filename="../src/mainwindow.cpp" line="806"/>
        <source>done.</source>
        <translation>fatto.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="330"/>
        <location filename="../src/mainwindow.cpp" line="807"/>
        <source>Used plugin: </source>
        <translation>Plugin usato: </translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="334"/>
        <location filename="../src/mainwindow.cpp" line="811"/>
        <source>Error while loading plugin.</source>
        <translation>Errore durante il caricamento del plugin.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="424"/>
        <source>An error was detected when starting the application.
The application will be closed.</source>
        <translation>È stato rilevato un errore all&apos;avvio dell&apos;applicazione.
L&apos;applicazione verrà chiusa.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="493"/>
        <source>No connection to the internet.</source>
        <translation>Nessuna connessione a Internet.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="493"/>
        <source>Please check your internet connection.</source>
        <translation>Si prega di controllare la connessione internet.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="796"/>
        <source>&amp;Provider</source>
        <translation>&amp;Provider</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="834"/>
        <source>&amp;About this picture and license</source>
        <translation>&amp;Informazioni su questa immagine e licenza</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="838"/>
        <source>&amp;About this picture and copyright</source>
        <translation>&amp;Informazioni su questa immagine e copyright</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="845"/>
        <source>&amp;Download past pictures</source>
        <translation>&amp;Scarica le immagini del passato</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="849"/>
        <source>&amp;Load stored picture</source>
        <translation>&amp;Carica immagine memorizzata</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="852"/>
        <source>&amp;Settings</source>
        <translation>&amp;Impostazioni</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="855"/>
        <source>&amp;About</source>
        <translation>&amp;Circa</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="858"/>
        <source>&amp;Quit</source>
        <translation>&amp;Dimettersi</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="873"/>
        <source>No internet connection.</source>
        <translation>Nessuna connessione internet.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="932"/>
        <source>Description: 
</source>
        <translation>Descrizione: 
</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1256"/>
        <source>Offline</source>
        <translation>Offline</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1257"/>
        <source>No internet connection available.</source>
        <translation>Nessuna connessione internet.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1518"/>
        <source>Load plugin...</source>
        <translation>Carica plugin...</translation>
    </message>
</context>
<context>
    <name>PhotoBrowser</name>
    <message>
        <location filename="../src/photobrowser.ui" line="20"/>
        <location filename="../src/photobrowser.ui" line="58"/>
        <source>Load stored picture</source>
        <translation>Carica immagine memorizzata</translation>
    </message>
    <message>
        <location filename="../src/photobrowser.ui" line="90"/>
        <location filename="../src/photobrowser.ui" line="187"/>
        <source>&amp;Set as wallpaper</source>
        <translation>&amp;Imposta come sfondo</translation>
    </message>
    <message>
        <location filename="../src/photobrowser.ui" line="174"/>
        <source>Select a photo</source>
        <translation>Seleziona una foto</translation>
    </message>
    <message>
        <location filename="../src/photobrowser.ui" line="282"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:700;&quot;&gt;Select date: &lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:700;&quot;&gt;Seleziona la data: &lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../src/photobrowser.ui" line="325"/>
        <source>&amp;Set current date</source>
        <translation>&amp;Imposta la data corrente</translation>
    </message>
    <message>
        <location filename="../src/photobrowser.ui" line="382"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Show photos of past days: &lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Mostra le foto dei giorni passati: &lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../src/photobrowser.ui" line="449"/>
        <source>&amp;Show pictures</source>
        <translation>&amp;Mostra immagini</translation>
    </message>
    <message>
        <location filename="../src/photobrowser.cpp" line="209"/>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
    <message>
        <location filename="../src/photobrowser.cpp" line="209"/>
        <source>Error while loading plugin.</source>
        <translation>Errore durante il caricamento del plugin.</translation>
    </message>
    <message>
        <location filename="../src/photobrowser.cpp" line="214"/>
        <source>Past pictures of the day (Wikimedia Commons)</source>
        <translation>Foto passate del giorno (Wikimedia Commons)</translation>
    </message>
    <message>
        <location filename="../src/photobrowser.cpp" line="263"/>
        <source>Get more information</source>
        <translation>Richiedi maggiori informazioni</translation>
    </message>
    <message>
        <location filename="../src/photobrowser.cpp" line="430"/>
        <source>Details</source>
        <translation>Dettagli</translation>
    </message>
    <message>
        <location filename="../src/photobrowser.cpp" line="434"/>
        <source>Please select a picture.</source>
        <translation>Seleziona un&apos;immagine.</translation>
    </message>
    <message>
        <location filename="../src/photobrowser.cpp" line="442"/>
        <source>Title: </source>
        <translation>Titolo: </translation>
    </message>
    <message>
        <location filename="../src/photobrowser.cpp" line="448"/>
        <source>Description: </source>
        <translation>Descrizione: </translation>
    </message>
    <message>
        <location filename="../src/photobrowser.cpp" line="460"/>
        <source>Picture size:</source>
        <translation>Dimensioni immagine:</translation>
    </message>
    <message>
        <location filename="../src/photobrowser.cpp" line="470"/>
        <source>Preview:</source>
        <translation>Anteprima:</translation>
    </message>
    <message>
        <location filename="../src/photobrowser.cpp" line="508"/>
        <source>Download in progress...</source>
        <translation>Download in corso...</translation>
    </message>
    <message>
        <location filename="../src/photobrowser.cpp" line="551"/>
        <source>The entered date must not be in the future.</source>
        <translation>La data inserita non deve essere futura.</translation>
    </message>
    <message>
        <location filename="../src/photobrowser.cpp" line="641"/>
        <source>Working in progress...</source>
        <translation>In corso di lavorazione...</translation>
    </message>
</context>
<context>
    <name>QProgressDialog</name>
    <message>
        <source>Download in progress...</source>
        <translation type="vanished">Download in corso...</translation>
    </message>
    <message>
        <source>Working in progress...</source>
        <translation type="vanished">In corso di lavorazione...</translation>
    </message>
</context>
<context>
    <name>SettingsWindow</name>
    <message>
        <location filename="../src/settingswindow.ui" line="23"/>
        <source>Settings</source>
        <translation>Impostazioni</translation>
    </message>
    <message>
        <location filename="../src/settingswindow.ui" line="37"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Location to save background photos: &lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Posizione per salvare le foto di sfondo: &lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../src/settingswindow.ui" line="55"/>
        <source>Choose</source>
        <translation>Scegliere</translation>
    </message>
    <message>
        <location filename="../src/settingswindow.ui" line="72"/>
        <source>Delete wallpapers older than (days): </source>
        <translation>Eliminare gli sfondi più vecchi di (giorni): </translation>
    </message>
    <message>
        <location filename="../src/settingswindow.ui" line="121"/>
        <source>Change desktop background photo automatically</source>
        <translation>Cambia automaticamente la foto di sfondo del desktop</translation>
    </message>
    <message>
        <location filename="../src/settingswindow.ui" line="141"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Time of day for changing wallpaper automatically: &lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Ora del giorno per cambiare automaticamente lo sfondo: &lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../src/settingswindow.ui" line="181"/>
        <source>Run Application at startup</source>
        <translation>Esegui applicazione all&apos;avvio</translation>
    </message>
    <message>
        <location filename="../src/settingswindow.ui" line="198"/>
        <source>Change lock screen wallpaper if possible</source>
        <translation>Cambia lo sfondo della schermata di blocco, se possibile</translation>
    </message>
    <message>
        <location filename="../src/settingswindow.ui" line="240"/>
        <location filename="../src/settingswindow.cpp" line="176"/>
        <source>Reset</source>
        <translation>Resettare</translation>
    </message>
    <message>
        <location filename="../src/settingswindow.ui" line="272"/>
        <source>Save settings</source>
        <translation>Salvare</translation>
    </message>
    <message>
        <location filename="../src/settingswindow.ui" line="291"/>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <location filename="../src/settingswindow.cpp" line="141"/>
        <source>Save changes</source>
        <translation>Salvare</translation>
    </message>
    <message>
        <location filename="../src/settingswindow.cpp" line="141"/>
        <source>The application will be restart for the changes to take effect. Do you want save the changes?</source>
        <translation>L&apos;applicazione verrà riavviata per rendere effettive le modifiche. Vuoi salvare le modifiche?</translation>
    </message>
    <message>
        <location filename="../src/settingswindow.cpp" line="155"/>
        <source>Select directory</source>
        <translation>Seleziona directory</translation>
    </message>
    <message>
        <location filename="../src/settingswindow.cpp" line="176"/>
        <source>This will reset all settings to the default settings. All existing wallpapers will be deleted. Do you want to continue?</source>
        <translation>In questo modo verranno ripristinate tutte le impostazioni predefinite. Tutti gli sfondi esistenti verranno eliminati. Vuoi continuare?</translation>
    </message>
</context>
<context>
    <name>setWallpaper</name>
    <message>
        <location filename="../src/setwallpaper.cpp" line="207"/>
        <source>Error: Failed to set wallpaper on macOS.</source>
        <translation>Errore - Impossibile impostare lo sfondo.</translation>
    </message>
    <message>
        <location filename="../src/setwallpaper.cpp" line="218"/>
        <source>Error - Failed to set wallpaper.</source>
        <translation>Errore - Impossibile impostare lo sfondo.</translation>
    </message>
</context>
</TS>
